import React, { useState } from 'react';
import { Input } from '@/Components/Base/Input/Input';
import { Button } from '@/Components/Base/Buttons/Button';
import styles from "@/Components/Form/SignUp/SignUp.module.css";
import { getUserByPhone } from '../../../Api/Api';
import 'react-toastify/dist/ReactToastify.css';

export const SignUp = ({
  onSignUpSubmit,
  label = "SignUp",
  namePlaceholder = "Name",
  emailPlaceholder = "Email",
  phonePlaceholder = "Phone Number",
}) => {
  const [formData, setFormData] = useState({
    name: '',
    email: '',
    phoneNumber: '',
  });

  const [errors, setErrors] = useState({
    name: '',
    email: '',
    phoneNumber: '',
  });

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setFormData((prev) => ({ ...prev, [name]: value }));
    setErrors((prev) => ({ ...prev, [name]: '' }));
  };

  const validateForm = () => {
    const newErrors = {};
    const { name, email, phoneNumber } = formData;

    if (!name.trim()) newErrors.name = 'Name is required';

    if (!email.trim()) {
      newErrors.email = 'Email is required';
    } else if (!/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)) {
      newErrors.email = 'Enter a valid email address';
    }

    if (!phoneNumber.trim()) {
      newErrors.phoneNumber = 'Phone number is required';
    } else if (phoneNumber.length < 10) {
      newErrors.phoneNumber = 'Phone number must contain at least 10 digits';
    } else if (!/^\+?\d{10,15}$/.test(phoneNumber)) {
      newErrors.phoneNumber = 'Phone number must contain only digits';
    }

    setErrors(newErrors);
    return Object.keys(newErrors).length === 0;
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    if (!validateForm()) return;

    try {
      await onSignUpSubmit?.(formData);
      setFormData({ name: '', email: '', phoneNumber: '' });
    } catch (error) {
      console.log(err);
    }
  };

  return (
    <div className={styles.SignUpContainer}>
      <div className={styles.wrapper}>
        <div className={styles.rightPane}>
          <form onSubmit={handleSubmit} className={styles.form}>
            <Input
              type="text"
              name="name"
              placeholder={namePlaceholder}
              value={formData.name}
              onChange={handleInputChange}
              errorMessage={errors.name}
              isInvalid={!!errors.name}
            />
            <Input
              type="text"
              name="email"
              placeholder={emailPlaceholder}
              value={formData.email}
              onChange={handleInputChange}
              errorMessage={errors.email}
              isInvalid={!!errors.email}
            />
            <Input
              type="text"
              name="phoneNumber"
              placeholder={phonePlaceholder}
              value={formData.phoneNumber}
              onChange={handleInputChange}
              errorMessage={errors.phoneNumber}
              isInvalid={!!errors.phoneNumber}
            />
            <Button variant="primary" label={label} size="md" />
          </form>
        </div>
      </div>
    </div>
  );
};