// Notification.jsx
import PropTypes from "prop-types";
import styles from "@/Components/Top-level/Notification/Notification.module.css";
import successImg from "@/assets/success.png";
import errorImg from "@/assets/giferror.gif";
import cn from "classnames";

export const Notification = ({ title, type, msg, button, seats }) => {
  const selectedImage = type === "success" ? successImg : errorImg;

  return (
    <div className={styles.container}>
      <span className={styles.span}>
        <img
          src={selectedImage}
          alt={type}
          className={cn(styles.imageEffect, {
            [styles.success]: type === "success",
            [styles.error]: type === "error",
          })}
        />
      </span>

      <h2 className={styles.title}>{title}</h2>
      <p className={styles.msg}>{msg}</p>

      {seats && seats.length > 0 && (
        <div className={styles.seatListWrapper}>
          <h4 className={styles.seatTitle}>🎫 Your Seats:</h4>
          <ul className={styles.seatList}>
            {seats.map((seat, index) => (
              <li key={index} className={styles.seatItem}>
                {seat}
              </li>
            ))}
          </ul>
        </div>
      )}

      <div className={styles.button}>{button}</div>
    </div>
  );
};

Notification.propTypes = {
  type: PropTypes.oneOf(["success", "error"]).isRequired,
  title: PropTypes.string.isRequired,
  msg: PropTypes.string.isRequired,
  button: PropTypes.element,
  seats: PropTypes.arrayOf(PropTypes.string), 
};
