import { useEffect, useState } from 'react';
import Confetti from 'react-confetti';
import { Notification } from "@/Components/Top-level/Notification/Notification";
import { Button } from "@/Components/Base/Buttons/Button";

export const Success = () => {
  const [showConfetti, setShowConfetti] = useState(true);
  const [windowSize, setWindowSize] = useState({ width: 0, height: 0 });
  const [bookedSeats, setBookedSeats] = useState([]);

  const response = {
    title: 'Success 🎉',
    type: 'success',
    msg: 'Successfully booked your ticket!',
  };

  useEffect(() => {
    setWindowSize({ width: window.innerWidth, height: window.innerHeight });
    const seats = JSON.parse(localStorage.getItem("bookedSeats")) || [];
    setBookedSeats(seats);
    // Confetti timeout
    const timer = setTimeout(() => {
      setShowConfetti(false);
    }, 10000);

    return () => clearTimeout(timer);
  }, []);

  const handleSuccess = () => {
    window.location.replace('/booking');
  };

  return (
    <>
      {showConfetti && (
        <Confetti width={windowSize.width} height={windowSize.height} />
      )}

      <Notification
        {...response}
        seats={bookedSeats}
        button={
          <Button
            variant="secondary"
            label="Book more seats"
            size="md"
            onClick={handleSuccess}
          />
        }
      />
    </>
  );
};
