import PropTypes from 'prop-types';
import { useState, useEffect } from 'react';
import { Seat } from '@/Components/Top-level/Seat/Seat.jsx';
import styles from '@/Components/Top-level/SeatLayout/SeatLayout.module.css';
import { seatsData } from '@/Components/Top-level/SeatLayout/SeatsData.js';
import { toast } from 'react-toastify';

const populateSeatsArray = (selectedSeats, reservedSeats) => {
  return seatsData.map(({ row, seats }) =>
    seats.map((number) => {
      const seatNo = row + number;
      if (number === '/') return { seatNo, status: 'none' };
      if (reservedSeats.includes(seatNo)) return { seatNo, status: 'reserved' };
      if (selectedSeats.includes(seatNo)) return { seatNo, status: 'selected' };
      return { seatNo, status: 'available' };
    })
  );
};

export const SeatLayout = ({
  selectedSeats: initialSelected = [],
  reservedSeats,
  limit,
  onSelectionChange,
}) => {
  const [selectedSeats, setSelectedSeats] = useState(initialSelected);

  useEffect(() => {
    setSelectedSeats(initialSelected);
  }, [initialSelected]);

  const seatClickHandler = ({ seatNo, status }) => {
    if (status === 'reserved') return;

    const isSelected = selectedSeats.includes(seatNo);
    const updated = isSelected
      ? selectedSeats.filter((s) => s !== seatNo)
      : [...selectedSeats, seatNo];

    if (!isSelected && updated.length > limit) {
      toast.warn(`Only ${limit} seat${limit > 1 ? 's' : ''} allowed`);
      return;
    }

    setSelectedSeats(updated);
    onSelectionChange(updated); // fire callback
  };

  const renderedSeats = populateSeatsArray(selectedSeats, reservedSeats);

  return (
    <div className={styles.container}>
      {renderedSeats.map((row, i) => (
        <div key={i} className={styles.seatcontainer}>
          {row.map((seat, j) => (
            <Seat key={j} {...seat} onClick={() => seatClickHandler(seat)} />
          ))}
        </div>
      ))}
    </div>
  );
};

SeatLayout.propTypes = {
  selectedSeats: PropTypes.arrayOf(PropTypes.string),
  reservedSeats: PropTypes.arrayOf(PropTypes.string).isRequired,
  limit: PropTypes.number.isRequired,
  onSelectionChange: PropTypes.func,
};
